@@ -67,6 +67,7 @@ def main():
         default=[sys.stdin],
         help="input filenames",
     )
+    parser.add_argument("-d", "--debug", action="store_true", help=argparse.SUPPRESS)
     args = parser.parse_args()
 
     if args.in_place and args.input_files[0].name == "<stdin>":
@@ -77,12 +78,17 @@ def main():
 
     for input_file in args.input_files:
         source = input_file.read()
+
         try:
+            if args.debug:
+                print(Mode(source).debug())
+                sys.exit()
             result = Mode(source).indent(args.tabwidth)
         except SyntaxError as e:
             if not args.quiet:
                 print(
-                    f"Error in {input_file.name}: {str(e) or e.__class__.__name__}",
+                    f"Syntax error in {input_file.name}:"
+                    f" {str(e) or e.__class__.__name__}",
                     file=sys.stderr,
                 )
             exit_status = 1
@@ -106,10 +112,13 @@ def main():
                     file=sys.stderr,
                 )
         elif not args.quiet:
-            print(
-                f"{input_file.name} is perfectly indented!",
-                file=sys.stderr,
-            )
+            if not args.in_place and args.output_file == "-":
+                print(result, end="")
+            else:
+                print(
+                    f"{input_file.name} is perfectly indented!",
+                    file=sys.stderr,
+                )
 
     sys.exit(exit_status)
 
